==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/services/ec2/CfnVPCEndpointServiceProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::VPCEndpointService`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:26:16.677Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_ec2.CfnVPCEndpointServiceProps")
@software.amazon.jsii.Jsii.Proxy(CfnVPCEndpointServiceProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnVPCEndpointServiceProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::EC2::VPCEndpointService.AcceptanceRequired`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAcceptanceRequired() {
        return null;
    }

    /**
     * `AWS::EC2::VPCEndpointService.GatewayLoadBalancerArns`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getGatewayLoadBalancerArns() {
        return null;
    }

    /**
     * `AWS::EC2::VPCEndpointService.NetworkLoadBalancerArns`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getNetworkLoadBalancerArns() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnVPCEndpointServiceProps> {
        private java.lang.Object acceptanceRequired;
        private java.util.List<java.lang.String> gatewayLoadBalancerArns;
        private java.util.List<java.lang.String> networkLoadBalancerArns;

        /**
         * Sets the value of {@link CfnVPCEndpointServiceProps#getAcceptanceRequired}
         * @param acceptanceRequired `AWS::EC2::VPCEndpointService.AcceptanceRequired`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder acceptanceRequired(java.lang.Boolean acceptanceRequired) {
            this.acceptanceRequired = acceptanceRequired;
            return this;
        }

        /**
         * Sets the value of {@link CfnVPCEndpointServiceProps#getAcceptanceRequired}
         * @param acceptanceRequired `AWS::EC2::VPCEndpointService.AcceptanceRequired`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder acceptanceRequired(software.amazon.awscdk.IResolvable acceptanceRequired) {
            this.acceptanceRequired = acceptanceRequired;
            return this;
        }

        /**
         * Sets the value of {@link CfnVPCEndpointServiceProps#getGatewayLoadBalancerArns}
         * @param gatewayLoadBalancerArns `AWS::EC2::VPCEndpointService.GatewayLoadBalancerArns`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder gatewayLoadBalancerArns(java.util.List<java.lang.String> gatewayLoadBalancerArns) {
            this.gatewayLoadBalancerArns = gatewayLoadBalancerArns;
            return this;
        }

        /**
         * Sets the value of {@link CfnVPCEndpointServiceProps#getNetworkLoadBalancerArns}
         * @param networkLoadBalancerArns `AWS::EC2::VPCEndpointService.NetworkLoadBalancerArns`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder networkLoadBalancerArns(java.util.List<java.lang.String> networkLoadBalancerArns) {
            this.networkLoadBalancerArns = networkLoadBalancerArns;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVPCEndpointServiceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnVPCEndpointServiceProps build() {
            return new Jsii$Proxy(acceptanceRequired, gatewayLoadBalancerArns, networkLoadBalancerArns);
        }
    }

    /**
     * An implementation for {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnVPCEndpointServiceProps {
        private final java.lang.Object acceptanceRequired;
        private final java.util.List<java.lang.String> gatewayLoadBalancerArns;
        private final java.util.List<java.lang.String> networkLoadBalancerArns;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.acceptanceRequired = software.amazon.jsii.Kernel.get(this, "acceptanceRequired", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.gatewayLoadBalancerArns = software.amazon.jsii.Kernel.get(this, "gatewayLoadBalancerArns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.networkLoadBalancerArns = software.amazon.jsii.Kernel.get(this, "networkLoadBalancerArns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Object acceptanceRequired, final java.util.List<java.lang.String> gatewayLoadBalancerArns, final java.util.List<java.lang.String> networkLoadBalancerArns) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.acceptanceRequired = acceptanceRequired;
            this.gatewayLoadBalancerArns = gatewayLoadBalancerArns;
            this.networkLoadBalancerArns = networkLoadBalancerArns;
        }

        @Override
        public final java.lang.Object getAcceptanceRequired() {
            return this.acceptanceRequired;
        }

        @Override
        public final java.util.List<java.lang.String> getGatewayLoadBalancerArns() {
            return this.gatewayLoadBalancerArns;
        }

        @Override
        public final java.util.List<java.lang.String> getNetworkLoadBalancerArns() {
            return this.networkLoadBalancerArns;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAcceptanceRequired() != null) {
                data.set("acceptanceRequired", om.valueToTree(this.getAcceptanceRequired()));
            }
            if (this.getGatewayLoadBalancerArns() != null) {
                data.set("gatewayLoadBalancerArns", om.valueToTree(this.getGatewayLoadBalancerArns()));
            }
            if (this.getNetworkLoadBalancerArns() != null) {
                data.set("networkLoadBalancerArns", om.valueToTree(this.getNetworkLoadBalancerArns()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_ec2.CfnVPCEndpointServiceProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnVPCEndpointServiceProps.Jsii$Proxy that = (CfnVPCEndpointServiceProps.Jsii$Proxy) o;

            if (this.acceptanceRequired != null ? !this.acceptanceRequired.equals(that.acceptanceRequired) : that.acceptanceRequired != null) return false;
            if (this.gatewayLoadBalancerArns != null ? !this.gatewayLoadBalancerArns.equals(that.gatewayLoadBalancerArns) : that.gatewayLoadBalancerArns != null) return false;
            return this.networkLoadBalancerArns != null ? this.networkLoadBalancerArns.equals(that.networkLoadBalancerArns) : that.networkLoadBalancerArns == null;
        }

        @Override
        public final int hashCode() {
            int result = this.acceptanceRequired != null ? this.acceptanceRequired.hashCode() : 0;
            result = 31 * result + (this.gatewayLoadBalancerArns != null ? this.gatewayLoadBalancerArns.hashCode() : 0);
            result = 31 * result + (this.networkLoadBalancerArns != null ? this.networkLoadBalancerArns.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/ec2/CfnVPCEndpointServiceProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `CfnVPCEndpointService`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ec2.*;
 * CfnVPCEndpointServiceProps cfnVPCEndpointServiceProps = CfnVPCEndpointServiceProps.builder()
 *         .acceptanceRequired(false)
 *         .gatewayLoadBalancerArns(List.of("gatewayLoadBalancerArns"))
 *         .networkLoadBalancerArns(List.of("networkLoadBalancerArns"))
 *         .payerResponsibility("payerResponsibility")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:09.217Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_ec2.CfnVPCEndpointServiceProps")
@software.amazon.jsii.Jsii.Proxy(CfnVPCEndpointServiceProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnVPCEndpointServiceProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Indicates whether requests from service consumers to create an endpoint to your service must be accepted.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAcceptanceRequired() {
        return null;
    }

    /**
     * The Amazon Resource Names (ARNs) of one or more Gateway Load Balancers.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getGatewayLoadBalancerArns() {
        return null;
    }

    /**
     * The Amazon Resource Names (ARNs) of one or more Network Load Balancers for your service.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getNetworkLoadBalancerArns() {
        return null;
    }

    /**
     * The entity that is responsible for the endpoint costs.
     * <p>
     * The default is the endpoint owner. If you set the payer responsibility to the service owner, you cannot set it back to the endpoint owner.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getPayerResponsibility() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnVPCEndpointServiceProps> {
        java.lang.Object acceptanceRequired;
        java.util.List<java.lang.String> gatewayLoadBalancerArns;
        java.util.List<java.lang.String> networkLoadBalancerArns;
        java.lang.String payerResponsibility;

        /**
         * Sets the value of {@link CfnVPCEndpointServiceProps#getAcceptanceRequired}
         * @param acceptanceRequired Indicates whether requests from service consumers to create an endpoint to your service must be accepted.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder acceptanceRequired(java.lang.Boolean acceptanceRequired) {
            this.acceptanceRequired = acceptanceRequired;
            return this;
        }

        /**
         * Sets the value of {@link CfnVPCEndpointServiceProps#getAcceptanceRequired}
         * @param acceptanceRequired Indicates whether requests from service consumers to create an endpoint to your service must be accepted.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder acceptanceRequired(software.amazon.awscdk.IResolvable acceptanceRequired) {
            this.acceptanceRequired = acceptanceRequired;
            return this;
        }

        /**
         * Sets the value of {@link CfnVPCEndpointServiceProps#getGatewayLoadBalancerArns}
         * @param gatewayLoadBalancerArns The Amazon Resource Names (ARNs) of one or more Gateway Load Balancers.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder gatewayLoadBalancerArns(java.util.List<java.lang.String> gatewayLoadBalancerArns) {
            this.gatewayLoadBalancerArns = gatewayLoadBalancerArns;
            return this;
        }

        /**
         * Sets the value of {@link CfnVPCEndpointServiceProps#getNetworkLoadBalancerArns}
         * @param networkLoadBalancerArns The Amazon Resource Names (ARNs) of one or more Network Load Balancers for your service.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder networkLoadBalancerArns(java.util.List<java.lang.String> networkLoadBalancerArns) {
            this.networkLoadBalancerArns = networkLoadBalancerArns;
            return this;
        }

        /**
         * Sets the value of {@link CfnVPCEndpointServiceProps#getPayerResponsibility}
         * @param payerResponsibility The entity that is responsible for the endpoint costs.
         *                            The default is the endpoint owner. If you set the payer responsibility to the service owner, you cannot set it back to the endpoint owner.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder payerResponsibility(java.lang.String payerResponsibility) {
            this.payerResponsibility = payerResponsibility;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVPCEndpointServiceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnVPCEndpointServiceProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnVPCEndpointServiceProps {
        private final java.lang.Object acceptanceRequired;
        private final java.util.List<java.lang.String> gatewayLoadBalancerArns;
        private final java.util.List<java.lang.String> networkLoadBalancerArns;
        private final java.lang.String payerResponsibility;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.acceptanceRequired = software.amazon.jsii.Kernel.get(this, "acceptanceRequired", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.gatewayLoadBalancerArns = software.amazon.jsii.Kernel.get(this, "gatewayLoadBalancerArns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.networkLoadBalancerArns = software.amazon.jsii.Kernel.get(this, "networkLoadBalancerArns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.payerResponsibility = software.amazon.jsii.Kernel.get(this, "payerResponsibility", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.acceptanceRequired = builder.acceptanceRequired;
            this.gatewayLoadBalancerArns = builder.gatewayLoadBalancerArns;
            this.networkLoadBalancerArns = builder.networkLoadBalancerArns;
            this.payerResponsibility = builder.payerResponsibility;
        }

        @Override
        public final java.lang.Object getAcceptanceRequired() {
            return this.acceptanceRequired;
        }

        @Override
        public final java.util.List<java.lang.String> getGatewayLoadBalancerArns() {
            return this.gatewayLoadBalancerArns;
        }

        @Override
        public final java.util.List<java.lang.String> getNetworkLoadBalancerArns() {
            return this.networkLoadBalancerArns;
        }

        @Override
        public final java.lang.String getPayerResponsibility() {
            return this.payerResponsibility;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAcceptanceRequired() != null) {
                data.set("acceptanceRequired", om.valueToTree(this.getAcceptanceRequired()));
            }
            if (this.getGatewayLoadBalancerArns() != null) {
                data.set("gatewayLoadBalancerArns", om.valueToTree(this.getGatewayLoadBalancerArns()));
            }
            if (this.getNetworkLoadBalancerArns() != null) {
                data.set("networkLoadBalancerArns", om.valueToTree(this.getNetworkLoadBalancerArns()));
            }
            if (this.getPayerResponsibility() != null) {
                data.set("payerResponsibility", om.valueToTree(this.getPayerResponsibility()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_ec2.CfnVPCEndpointServiceProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnVPCEndpointServiceProps.Jsii$Proxy that = (CfnVPCEndpointServiceProps.Jsii$Proxy) o;

            if (this.acceptanceRequired != null ? !this.acceptanceRequired.equals(that.acceptanceRequired) : that.acceptanceRequired != null) return false;
            if (this.gatewayLoadBalancerArns != null ? !this.gatewayLoadBalancerArns.equals(that.gatewayLoadBalancerArns) : that.gatewayLoadBalancerArns != null) return false;
            if (this.networkLoadBalancerArns != null ? !this.networkLoadBalancerArns.equals(that.networkLoadBalancerArns) : that.networkLoadBalancerArns != null) return false;
            return this.payerResponsibility != null ? this.payerResponsibility.equals(that.payerResponsibility) : that.payerResponsibility == null;
        }

        @Override
        public final int hashCode() {
            int result = this.acceptanceRequired != null ? this.acceptanceRequired.hashCode() : 0;
            result = 31 * result + (this.gatewayLoadBalancerArns != null ? this.gatewayLoadBalancerArns.hashCode() : 0);
            result = 31 * result + (this.networkLoadBalancerArns != null ? this.networkLoadBalancerArns.hashCode() : 0);
            result = 31 * result + (this.payerResponsibility != null ? this.payerResponsibility.hashCode() : 0);
            return result;
        }
    }
}
